#!/bin/sh

# Build script for fr-dvorak-bepo-keymap
# Author: Ejis <ejis at mailoo.org>

# Homepage: http://www.bepo.fr/


# Stop when an error occurs.

set -e


# These variables set the name of the package, its version,
# which Zenwalk version it's built for and the number of this
# build for this version.

SOFTNAME=fr-dvorak-bepo-keymap
DLNAME=fr-dvorak-bepo-keymaps
VERSION=1.0rc2
BUILD=2
MAINTAINER=ej
BUILDVER=${BUILD}${MAINTAINER}

# Zenwalk category of the package (e.g.: extra/xap)

CATEGORY=extra

# The architecture this package is built for. It will be mostly
# i486, but when the package won't run right on i486, this value
# can be i686.
# This determines the flags to use during compile.

MARCH="x86_64"
FLAGS="-O2 -fPIC"
LDFLAGS="-L/usr/lib64"

# The DOTNEW variable tells the buildscript if it should convert
# every file in /etc to .new files, preventing previously
# installed files to be erased after an upgrade.
# The DOINST variable tells the buildscript to create a
# doinst.sh file, that contains post-install commands.

DOTNEW=1
DOINST=0

# Current directory.

CWD=$(pwd)

# Name of the package file before the extension.

PKG=$SOFTNAME-$VERSION-$MARCH-$BUILDVER

# Source directory and the directory where the package will be
# installed before compression.

SOFTDIR=$CWD/$DLNAME-$VERSION
PKGDIR=$CWD/$PKG

# Files created by the script.
# The .txz file is the package file, the .md5 is its md5sum, the
# .src file is the file that contains the URLs where to download
# the files used for building and the .dep file is the list of
# the dependencies.

PKGFILE=$PKGDIR.txz
MD5=$PKGDIR.md5
SRC=$PKGDIR.src
DEP=$PKGDIR.dep

# Files needed to make the package. Most of the time, it will
# only be the source tarball, but sometimes, some extra files
# are needed, like patches or icon images.
# Some files are kept in /usr/src. The buildscript is
# mandatory but some of the source files can also be added if
# they are small files.

SRCFILES=(
	$DLNAME-$VERSION.tgz
)
KEPTSRC=(
	$CWD/build-$SOFTNAME.sh
)

# The host url is the url where you will be able to find the
# package files.
# The source URLs are the URLs where the source files can be
# found. Sometimes, it can be the host URL.

HOSTURL=http://zenwalk.pinguix.com/user-accounts/ejis/$CATEGORY/$SOFTNAME
SRCURLS=(
	http://download.tuxfamily.org/dvorak/keymaps
)

# When the source files and URLs are set, the complete links
# to them must be set.

SRCLINKS=(
	${SRCURLS[0]}/${SRCFILES[0]}
)

# These files will be put in /usr/doc. These are mostly the text
# files you find in the source directory.

DOC=(
	$SOFTDIR/CC-SA-BY.txt
	$SOFTDIR/GFDL.txt
	$SOFTDIR/LISEZ_MOI.txt
)

# Sometimes, some dependencies can't be found, so they must be
# named in order to be added to the .dep file.
# On the other hand, some dependencies can be wrong or
# unnecessary, so they should be removed from the .dep file.

EXTRADEPS=(
)

LESSDEPS=(
)


# Check for source files and download them if necessary

if [ ! -f ${SRCFILES[0]} ]; then
	wget -c -t 0 -T 50 -w 0 ${SRCLINKS[0]}
  #wget -c -t 0 -T 50 -w 0 ${SRCLINKS[0]} -O ${SRCFILES[0]}
fi


# Erase the previous build files

rm -rf $PKGFILE $SOFTDIR $PKGDIR $MD5 $SRC $DEP
mkdir -p $PKG


# Build

echo ""
echo "-----Building-----"
echo ""

tar -xvf $CWD/${SRCFILES[0]}

cd $SOFTDIR

mkdir -pv $PKGDIR/usr/share/kbd/keymaps/i386/dvorak

gzip fr-dvorak-bepo.map
cp -v fr-dvorak-bepo.map.gz $PKGDIR/usr/share/kbd/keymaps/i386/dvorak/


# Packaging

echo ""
echo "-----Packaging-----"
echo ""

cd $PKGDIR

mkdir -p $PKGDIR/install
mkdir -p $PKGDIR/usr/doc/$SOFTNAME-$VERSION


	       #|-----handy-ruler------------------------------------------------------|
cat << EOF > $PKGDIR/install/slack-desc
$SOFTNAME: $SOFTNAME
$SOFTNAME:
$SOFTNAME: The bépo keyboard layout.
$SOFTNAME: 
$SOFTNAME: 
$SOFTNAME: 
$SOFTNAME: 
$SOFTNAME: 
$SOFTNAME: 
$SOFTNAME: 
$SOFTNAME: 
EOF


# Redundent

if [ -d $PKGDIR/usr/share/doc ]; then
	mv $PKGDIR/usr/share/doc/$SOFTNAME/* $PKGDIR/usr/doc/$SOFTNAME-$VERSION/
	rm -rvf $PKGDIR/usr/share/doc
fi

if [ -d $PKGDIR/etc ]; then
	if [ $DOTNEW == 1 ]; then
		dotnewfiles=$(find $PKGDIR/etc -type f -print -exec \
			mv {} {}.new \;)
		cat << EOF > $PKGDIR/install/doinst.sh
dotnewfiles=(${dotnewfiles[@]})

for file in \${dotnewfiles[@]}; do
	if [ ! -f \$file ]; then
		mv \$file.new \$file
	fi
done
EOF
		sed -i "s:$PKGDIR/::g" $PKGDIR/install/doinst.sh
	fi
fi

if [ $DOINST == 1 ]; then
	cat << EOF >> $PKGDIR/install/doinst.sh

EOF
fi

find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | \
	xargs strip --strip-unneeded 2> /dev/null || true
find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | \
	xargs strip --strip-unneeded 2> /dev/null || true

if [ -d $PKGDIR/usr/man ]; then
	
	( cd $PKGDIR/usr/man
		find . -type f -exec gzip -9 {} \;
		for i in $( find . -type l ) ; do ln -s $( readlink $i ).gz $i.gz ; rm $i ; done
	)
	
fi

if [ -d $PKGDIR/usr/info ]; then
	
	rm -f $PKGDIR/usr/info/dir
	gzip -9 $PKGDIR/usr/info/*.info*
	
fi

find . -name perllocal.pod \
	-o -name ".packlist" \
	-o -name "*.bs" \
	| xargs rm -f


cp -v ${KEPTSRC[@]} $PKGDIR/usr/doc/$SOFTNAME-$VERSION/
cp -rv	${DOC[@]} $PKGDIR/usr/doc/$SOFTNAME-$VERSION/


# fix permissions
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;


fakeroot /sbin/makepkg -l y -c n $PKGFILE


cd $CWD

echo 'Creating .md5 file'
md5sum $PKG.txz > $MD5

echo 'Creating .src file'
echo "$HOSTURL/build-$SOFTNAME.sh" > $SRC
for link in ${SRCLINKS[@]}; do
	echo $link >> $SRC
done

echo 'Checking for dependencies'
deps=$(depfinder -ap -j2 $PKGFILE)

for dep in ${EXTRADEPS[@]}; do
	deps="$deps,$dep"
done

for dep in ${LESSDEPS[@]}; do
	deps=${deps/$dep/}
done

order=$(echo ${deps//,/ } | sort -d)
echo ${order// /,} > $DEP
